<?php

namespace App\Service;

use App\Exception;

use SimpleXMLElement;

class IntegrationService {
    
    private $util;
    private $integrationFactory;

    public function __construct (\App\Util\Util $util,
                                 \App\Factory\IntegrationFactory $integrationFactory) {

        $this->util                 = $util;
        $this->integrationFactory   = $integrationFactory;
    }
    
    public function buildXmlString($content, $message = '', $error = ''){
        $xmlRef = new \SimpleXMLElement('<root/>');
        
        if($message !== ''){
            $content['message'] = $message;
        }
        
        if($error !== ''){
            $content['error'] = ($error ? 'true' : 'false');
        }
        
        $this->buildXml($content, $xmlRef);
        
        $xmlString = preg_replace('/ xmlns=""\s?/', '', $xmlRef->asXML());
        return $xmlString;
    }
    
    private function buildXml($content, &$xmlRef){
        $auxArray = $content;
        
        if(!empty($content)){
            foreach($auxArray as $contentChild){
                $childName = array_search($contentChild, $auxArray);
                
                if(is_array($contentChild)){
                    if(is_string($childName)){
                        $childXmlRef = $xmlRef->addChild($childName, "", '');
                    } else{
                        $childXmlRef = $xmlRef->addChild('data', "", '');
                    }
                    
                    $this->buildXml($contentChild, $childXmlRef);
                }
                
                else{
                    if($childName === 'cardPassword'){
                        $xmlRef->addChild($childName, $this->mask($contentChild, 2, 1), '');
                    } else{
                        if($contentChild === true){
                            $xmlRef->addChild($childName, 'true', '');
                        } else if($contentChild === false){
                            $xmlRef->addChild($childName, 'false', '');
                        } else if($contentChild === null){
                            $xmlRef->addChild($childName, 'null', '');
                        } else{
                            $xmlRef->addChild($childName, $contentChild, '');
                        }
                    }
                }
                
                unset($auxArray[$childName]);
            }
        }
    }
    
    public function saveRequestLog($fileName, $content, $logType) {
        try {
            $configsFile  = file_get_contents(__DIR__ . "/../../configs/configs.json");
            $config       = json_decode($configsFile, true);
            
            $logPath = $config['logPath'];
            
            $folder = $logPath . "/$logType/" . date("Y") . "/" . date("m") . "/" . date("d") . "/";
            $currentFile = $folder . "/" . $fileName;
            
            if(!file_exists($folder)) {
                mkdir($folder, 0775, true);
            }

            file_put_contents($currentFile, $content, FILE_APPEND);
        } catch(\Exception $e) { 

        }
    }
    
    private function mask($str, $first, $last) {
        $len = strlen($str);
        $toShow = $first + $last;
        return substr($str, 0, $len <= $toShow ? 0 : $first).str_repeat("*", $len - ($len <= $toShow ? 0 : $toShow)).substr($str, $len - $last, $len <= $toShow ? 0 : $last);
    }

}
